<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AddBlock</name>
    <message>
        <source>&amp;Add Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Dodaj blok</translatorcomment>
        <translation type="obsolete">&amp;Dodaj blok</translation>
    </message>
    <message>
        <location filename="../AddBlockInit.js" line="+2"/>
        <source>&amp;Add Empty Block</source>
        <translation>&amp;Dodaj pusty blok</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Add new empty block</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dodaje nowy, pusty blok</translation>
    </message>
</context>
</TS>
